process
-------

.. inheritance-diagram:: climlab.process.process
   :parts: 1
   :private-bases:
   
.. automodule:: climlab.process.process
    :members:
    :undoc-members:
    :show-inheritance:       